@@ -2,6 +2,7 @@ from typing import Optional, List
 
 from camel_model.camel_model import CamelModel
 
+from xlsx_lib.domain.abs.AbsData import AbsData
 from xlsx_lib.domain.autodiagnosis.AutodiagnosisData import AutodiagnosisData
 from xlsx_lib.domain.distribution.distribution_data import DistributionData
 from xlsx_lib.domain.power_supply.power_supply_component import PowerSupplyComponent
@@ -23,3 +24,4 @@ class MotorcycleModel(CamelModel):
     power_supply: Optional[List[PowerSupplyComponent]]
     distribution: Optional[DistributionData]
     autodiagnosis: Optional[AutodiagnosisData]
+    absData: Optional[AbsData]
