@@ -5,6 +5,8 @@ from openpyxl import \
     Workbook, \
     load_workbook
 
+from xlsx_lib.domain.abs.AbsData import AbsData
+from xlsx_lib.domain.abs.AbsSheet import AbsSheet
 from xlsx_lib.domain.autodiagnosis.AutodiagnosisData import AutodiagnosisData
 from xlsx_lib.domain.autodiagnosis.AutodiagnosisSheet import AutodiagnosisSheet
 from xlsx_lib.domain.distribution.new_distribution_image import NewDistributionImage
@@ -37,6 +39,7 @@ sheetnames_relationships = {
     "ALIM": Sheetnames.POWER_SUPPLY,
     "DISTRIBUCION": Sheetnames.DISTRIBUTION,
     "AUTODIAGNOSIS": Sheetnames.AUTODIAGNOSIS,
+    "ABS": Sheetnames.ABS,
 }
 
 
@@ -64,6 +67,7 @@ class MotorcycleModelWorkbook:
         power_supply_components: Optional[List[PowerSupplyComponent]] = None
         distribution: Optional[DistributionData] = None
         autodiagnosis: Optional[AutodiagnosisData] = None
+        absData: Optional[AbsData] = None
 
         for sheetname in [key for key in workbook.sheetnames
                           if key in sheetnames_relationships]:
@@ -99,6 +103,9 @@ class MotorcycleModelWorkbook:
             elif Sheetnames.AUTODIAGNOSIS == sheetnames_relationships[sheetname]:
                 autodiagnosis = AutodiagnosisSheet(worksheet=workbook[sheetname]).autodiagnosis
 
+            elif Sheetnames.ABS == sheetnames_relationships[sheetname]:
+                absData = AbsSheet(worksheet=workbook[sheetname]).abs
+
         self.motorcycle_model = MotorcycleModel(
             model_name=model_name,
             generic_replacements=generic_replacements,
@@ -109,4 +116,5 @@ class MotorcycleModelWorkbook:
             power_supply=power_supply_components,
             distribution=distribution,
             autodiagnosis=autodiagnosis,
+            absData=absData,
         )
